// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#ifndef ECM_QLOGGINGCATEGORY_KSCREENLOCKER_GREET_KSCREENLOCKER_GREET_LOGGING_H
#define ECM_QLOGGINGCATEGORY_KSCREENLOCKER_GREET_KSCREENLOCKER_GREET_LOGGING_H

#include <QLoggingCategory>

Q_DECLARE_LOGGING_CATEGORY(KSCREENLOCKER_GREET)


#endif
